#
# <konic-darksub.cl>
#
# IRAF batch script to select and combine dark frames and make it subtract 
# from raw object frames.
#
#                            2008.09.29.  Ver.0.1 second version. 
#                            2008.09.19.  Ver.0.0 Earliest version. 
#
# This IRAF batch script can select and combine dark frames and make it subtract 
# from raw object frames in input file list. Input file list should be named 
# "konic-rawtmp.lst" and include data frame names with same filter-band and with same 
# exposure time. Raw data files should be located in "RAW" directory.  
# Therefore, the content of "konic-rawtmp.lst" is written 
#    RAW/KIR*****.fits
#    RAW/KIR*****.fits
#    RAW/KIR*****.fits
#     : /KIR  :  .fits
#
# [USAGE] cl < konic-darksub.cl[RET]
#
# 0. Removing all temporal "___*.*" files.
#
!\rm ___*.*
#
# 1.0 Making directory to put result images.
#
!\mkdir DS
#
# 1.1 Making data list.
#
imhe @konic-rawtmp.lst l+ > ___konic-rawhead.dat 
#
# 1.2 Extracting Object names.
#
!grep "OBJECT" ___konic-rawhead.dat > ___konic-object0.dat
!awk '{print substr($3,2)}' ___konic-object0.dat > ___konic-object1.dat
#
# 1.3 Extracting Filter types.
#
!grep "FILTER" ___konic-rawhead.dat > ___konic-filter0.dat
!awk '{print substr($3,2)}' ___konic-filter0.dat > ___konic-filter1.dat
#
# 1.4 Outputing observation-log.
#
!paste konic-rawtmp.lst ___konic-object1.dat ___konic-filter1.dat > ___simple-obs.log
#
# 1.5 Making dark frame.
#
!awk '{if($3=="DARK"){print $1}}' ___simple-obs.log > ___dark.lst
imstat @___dark.lst
imcombine input=@___dark.lst output=___dark.fits combine=average reject=avsigclip offsets=none
display ___dark.fits 1
#
# 1.6 Dark subtraction from raw object frames.
#
!awk '{if(substr($3,1,1)=="J" || substr($3,1,1)=="H" || substr($3,1,1)=="K"){print $1}}' ___simple-obs.log > ___object.lst
!awk '{print "DS/ds"substr($1,8)}' ___object.lst > ___dsobj.lst
imarith @___object.lst - ___dark.fits @___dsobj.lst
#
# 1.5 Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
#
!echo Dark subtraction have been finished !
#
# End script.
#
#          Shingo Nishiura
#            Department of Astronomy and Earth Sciences, 
#                              Tokyo Gakugei University
#          e-mail: nishiura@u-gakugei.ac.jp
# 
