#
# <konic-ffobjK.cl>
#
# IRAF batch script to flat-fielding dark subtracted K'-band object frames.
#
#                            2008.09.19.  Ver.0.0 Earliest version. 
#                            2008.09.29.  Ver.0.1 Separatting and Flat-fielding version. 
#
# This IRAF batch script makes dark subtracted K'-band object frames 
# been flat-fielded.   
# Dark subtracted object images should be put in "DS" directory.
# "FlatK.fits" file is need and should be put in current directory.
# This script will make "FF" directory in current directory and output 
# "ff*.fits" files in it.
#
# [USAGE] cl < konic-ffobjK.cl[RET]
#
# 0. Removing all temporal "___*.*" files.
#
!\rm ___*.*
#
# 1.0 Making directory to put flat-fielded images.
#
!\mkdir FFU
!\mkdir FFL
#
# 1.1 Making data list.
#
!ls -1 DSU/ds*U.fits > ___dsobju.lst
!ls -1 DSL/ds*L.fits > ___dsobjl.lst
imhe @___dsobju.lst l+ > ___konic-dsobju.dat 
imhe @___dsobjl.lst l+ > ___konic-dsobjl.dat 
#
# 1.2 Extracting Object names.
#
!grep "OBJECT" ___konic-dsobju.dat > ___konic-dsobj0u.dat
!grep "OBJECT" ___konic-dsobjl.dat > ___konic-dsobj0l.dat
!awk '{print substr($3,2)}' ___konic-dsobju0.dat > ___konic-dsobju1.dat
!awk '{print substr($3,2)}' ___konic-dsobjl0.dat > ___konic-dsobjl1.dat
#
# 1.3 Extracting Filter types.
#
!grep "FILTER" ___konic-dsobju.dat > ___konic-filteru0.dat
!grep "FILTER" ___konic-dsobjl.dat > ___konic-filterl0.dat
!awk '{print substr($3,2)}' ___konic-filteru0.dat > ___konic-filteru1.dat
!awk '{print substr($3,2)}' ___konic-filterl0.dat > ___konic-filterl1.dat
#
# 1.4 Outputing observation-log.
#
!paste ___dsobju.lst ___konic-dsobju1.dat ___konic-filteru1.dat > ___simple-obsu.log
!paste ___dsobjl.lst ___konic-dsobjl1.dat ___konic-filterl1.dat > ___simple-obsl.log
#
# 1.5 Flat-fielding dark subtracted frames.
#
!awk '{if(substr($3,1,1)=="K"){print $1}}' ___simple-obsu.log > ___dsobjKu.lst
!awk '{if(substr($3,1,1)=="K"){print $1}}' ___simple-obsl.log > ___dsobjKl.lst
!awk '{print "FFU/ff"substr($1,7)}' ___dsobjKu.lst > ___ffobjKu.lst
!awk '{print "FFL/ff"substr($1,7)}' ___dsobjKl.lst > ___ffobjKl.lst
imarith @___dsobjKu.lst / FlatKu.fits @___ffobjKu.lst
imarith @___dsobjKl.lst / FlatKl.fits @___ffobjKl.lst
#
# 2.0 Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
#
!echo K'-band flat-fielding have been finished.
#
# End script.
#
#          Shingo Nishiura
#            Department of Astronomy and Earth Sciences, 
#                              Tokyo Gakugei University
#          e-mail: nishiura@u-gakugei.ac.jp
# 
