#
# <konic-flatcombH-mod.cl>
#
# IRAF batch script to combine H-band dome-flat frames.
#
#                            2008.09.19.  Ver.0.0 Earliest version. 
#                            2008.09.29.  Ver.0.1 Separatting and Combining version. 
#
# This IRAF batch script can select dark subtracted H-band object frames,  
# and normalize and combine them to H-band self-flat image. Adopted 
# image normalized option is "mode".
# Dark subtracted object images should be put in "DS" directory.
# This script will output "FlatH-mod.fits" file in current directory.
#
# [USAGE] cl < konic-flatcombH-mod.cl[RET]
#
# 0. Removing all temporal "___*.*" files.
#
!\rm ___*.*
#
# 1.0 Making directory to put normalized images.
#
!\mkdir NMU
!\mkdir NML
#
# 1.1 Making data list.
#
!ls -1 DSU/ds*U.fits > ___dsobju.lst
!ls -1 DSL/ds*L.fits > ___dsobjl.lst
imhe @___dsobju.lst l+ > ___konic-dsobju.dat 
imhe @___dsobjl.lst l+ > ___konic-dsobjl.dat 
#
# 1.2 Extracting Object names.
#
!grep "OBJECT" ___konic-dsobju.dat > ___konic-dsobju0.dat
!grep "OBJECT" ___konic-dsobjl.dat > ___konic-dsobjl0.dat
!awk '{print substr($3,2)}' ___konic-dsobju0.dat > ___konic-dsobju1.dat
!awk '{print substr($3,2)}' ___konic-dsobjl0.dat > ___konic-dsobjl1.dat
#
# 1.3 Extracting Filter types.
#
!grep "FILTER" ___konic-dsobju.dat > ___konic-filteru0.dat
!grep "FILTER" ___konic-dsobjl.dat > ___konic-filterl0.dat
!awk '{print substr($3,2)}' ___konic-filteru0.dat > ___konic-filteru1.dat
!awk '{print substr($3,2)}' ___konic-filterl0.dat > ___konic-filterl1.dat
#
# 1.4 Outputing observation-log.
#
!paste ___dsobju.lst ___konic-dsobju1.dat ___konic-filteru1.dat > ___simple-obsu.log
!paste ___dsobjl.lst ___konic-dsobjl1.dat ___konic-filterl1.dat > ___simple-obsl.log
#
# 1.5 Normalizing each H-band dome flat frame.
#
!awk '{if($3=="H"){print $1}}' ___simple-obsu.log > ___dsflatHu.lst
!awk '{if($3=="H"){print $1}}' ___simple-obsl.log > ___dsflatHl.lst
!awk '{print "NMU/nm"substr($1,7)}' ___dsflatHu.lst > ___nmflatHu.lst
!awk '{print "NML/nm"substr($1,7)}' ___dsflatHl.lst > ___nmflatHl.lst
imstat @___dsflatHu.lst fields=mode format=no > ___dsflatHu_mod.dat
imstat @___dsflatHl.lst fields=mode format=no > ___dsflatHl_mod.dat
imarith @___dsflatHu.lst / @___dsflatHu_mod.dat @___nmflatHu.lst
imarith @___dsflatHl.lst / @___dsflatHl_mod.dat @___nmflatHl.lst
#
# 1.6 Combinning H-band dome flat image.
#
imcombine input=@___nmflatHu.lst output=FlatHu-mod.fits combine=median offsets=none
imcombine input=@___nmflatHl.lst output=FlatHl-mod.fits combine=median offsets=none
#
# 2.0 Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
!\rm -rf NMU
!\rm -rf NML
#
!echo H-band Dome Flat was combined.
#
# End script.
#
#          Shingo Nishiura
#            Department of Astronomy and Earth Sciences, 
#                              Tokyo Gakugei University
#          e-mail: nishiura@u-gakugei.ac.jp
# 
