#
# <konic-flatcombJ-mid.cl>
#
# IRAF batch script to combine J-band dome-flat frames.
#
#                            2008.09.19.  Ver.0.0 Earliest version. 
#                            2008.09.29.  Ver.0.1 Separatting and Combining version. 
#
# This IRAF batch script can select dark subtracted J-band object frames,  
# and normalize and combine them to J-band self-flat image. Adopted 
# image normalized option is "median".
# Dark subtracted object images should be put in "DS" directory.
# This script will output "FlatJ-mid.fits" file in current directory.
#
# [USAGE] cl < konic-flatcombJ-mid.cl[RET]
#
# 0. Removing all temporal "___*.*" files.
#
!\rm ___*.*
#
# 1.0 Making directory to put normalized images.
#
!\mkdir NMU
!\mkdir NML
#
# 1.1 Making data list.
#
!ls -1 DSU/ds*U.fits > ___dsobju.lst
!ls -1 DSL/ds*L.fits > ___dsobjl.lst
imhe @___dsobju.lst l+ > ___konic-dsobju.dat 
imhe @___dsobjl.lst l+ > ___konic-dsobjl.dat 
#
# 1.2 Extracting Object names.
#
!grep "OBJECT" ___konic-dsobju.dat > ___konic-dsobju0.dat
!grep "OBJECT" ___konic-dsobjl.dat > ___konic-dsobjl0.dat
!awk '{print substr($3,2)}' ___konic-dsobju0.dat > ___konic-dsobju1.dat
!awk '{print substr($3,2)}' ___konic-dsobjl0.dat > ___konic-dsobjl1.dat
#
# 1.3 Extracting Filter types.
#
!grep "FILTER" ___konic-dsobju.dat > ___konic-filteru0.dat
!grep "FILTER" ___konic-dsobjl.dat > ___konic-filterl0.dat
!awk '{print substr($3,2)}' ___konic-filteru0.dat > ___konic-filteru1.dat
!awk '{print substr($3,2)}' ___konic-filterl0.dat > ___konic-filterl1.dat
#
# 1.4 Outputing observation-log.
#
!paste ___dsobju.lst ___konic-dsobju1.dat ___konic-filteru1.dat > ___simple-obsu.log
!paste ___dsobjl.lst ___konic-dsobjl1.dat ___konic-filterl1.dat > ___simple-obsl.log
#
# 1.5 Normalizing each J-band dome flat frame.
#
!awk '{if($3=="J"){print $1}}' ___simple-obsu.log > ___dsflatJu.lst
!awk '{if($3=="J"){print $1}}' ___simple-obsl.log > ___dsflatJl.lst
!awk '{print "NMU/nm"substr($1,7)}' ___dsflatJu.lst > ___nmflatJu.lst
!awk '{print "NML/nm"substr($1,7)}' ___dsflatJl.lst > ___nmflatJl.lst
imstat @___dsflatJu.lst fields=midpt format=no > ___dsflatJu_mid.dat
imstat @___dsflatJl.lst fields=midpt format=no > ___dsflatJl_mid.dat
imarith @___dsflatJu.lst / @___dsflatJu_mid.dat @___nmflatJu.lst
imarith @___dsflatJl.lst / @___dsflatJl_mid.dat @___nmflatJl.lst
#
# 1.6 Combinning J-band dome flat image.
#
imcombine input=@___nmflatJu.lst output=FlatJu-mid.fits combine=median offsets=none
imcombine input=@___nmflatJl.lst output=FlatJl-mid.fits combine=median offsets=none
#
# 2.0 Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
!\rm -rf NMU
!\rm -rf NML
#
!echo J-band Dome Flat was combined.
#
# End script.
#
#          Shingo Nishiura
#            Department of Astronomy and Earth Sciences, 
#                              Tokyo Gakugei University
#          e-mail: nishiura@u-gakugei.ac.jp
# 
