#
# <konic-flatcombK-mod.cl>
#
# IRAF batch script to combine K'-band dome-flat frames.
#
#                            2008.09.19.  Ver.0.0 Earliest version. 
#                            2008.09.29.  Ver.0.1 Separatting and Combining version. 
#
# This IRAF batch script can select dark subtracted K'-band object frames,  
# and normalize and combine them to K'-band self-flat image. Adopted 
# image normalized option is "mode".
# Dark subtracted object images should be put in "DS" directory.
# This script will output "FlatK-mod.fits" file in current directory.
#
# [USAGE] cl < konic-flatcombK-mod.cl[RET]
#
# 0. Removing all temporal "___*.*" files.
#
!\rm ___*.*
#
# 1.0 Making directory to put normalized images.
#
!\mkdir NMU
!\mkdir NML
#
# 1.1 Making data list.
#
!ls -1 DSU/ds*U.fits > ___dsobju.lst
!ls -1 DSL/ds*L.fits > ___dsobjl.lst
imhe @___dsobju.lst l+ > ___konic-dsobju.dat 
imhe @___dsobjl.lst l+ > ___konic-dsobjl.dat 
#
# 1.2 Extracting Object names.
#
!grep "OBJECT" ___konic-dsobju.dat > ___konic-dsobju0.dat
!grep "OBJECT" ___konic-dsobjl.dat > ___konic-dsobjl0.dat
!awk '{print substr($3,2)}' ___konic-dsobju0.dat > ___konic-dsobju1.dat
!awk '{print substr($3,2)}' ___konic-dsobjl0.dat > ___konic-dsobjl1.dat
#
# 1.3 Extracting Filter types.
#
!grep "FILTER" ___konic-dsobju.dat > ___konic-filteru0.dat
!grep "FILTER" ___konic-dsobjl.dat > ___konic-filterl0.dat
!awk '{print substr($3,2)}' ___konic-filteru0.dat > ___konic-filteru1.dat
!awk '{print substr($3,2)}' ___konic-filterl0.dat > ___konic-filterl1.dat
#
# 1.4 Outputing observation-log.
#
!paste ___dsobju.lst ___konic-dsobju1.dat ___konic-filteru1.dat > ___simple-obsu.log
!paste ___dsobjl.lst ___konic-dsobjl1.dat ___konic-filterl1.dat > ___simple-obsl.log
#
# 1.5 Normalizing each K'-band dome flat frame.
#
!awk '{if(substr($3,1,1)=="K"){print $1}}' ___simple-obsu.log > ___dsflatKu.lst
!awk '{if(substr($3,1,1)=="K"){print $1}}' ___simple-obsl.log > ___dsflatKl.lst
!awk '{print "NMU/nm"substr($1,7)}' ___dsflatKu.lst > ___nmflatKu.lst
!awk '{print "NML/nm"substr($1,7)}' ___dsflatKl.lst > ___nmflatKl.lst
imstat @___dsflatKu.lst fields=mode format=no > ___dsflatKu_mod.dat
imstat @___dsflatKl.lst fields=mode format=no > ___dsflatKl_mod.dat
imarith @___dsflatKu.lst / @___dsflatKu_mod.dat @___nmflatKu.lst
imarith @___dsflatKl.lst / @___dsflatKl_mod.dat @___nmflatKl.lst
#
# 1.6 Combinning K'-band dome flat image.
#
imcombine input=@___nmflatKu.lst output=FlatKu-mod.fits combine=median offsets=none
imcombine input=@___nmflatKl.lst output=FlatKl-mod.fits combine=median offsets=none
#
# 2.0 Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
!\rm -rf NMU
!\rm -rf NML
#
!echo K'-band Dome Flat was combined.
#
# End script.
#
#          Shingo Nishiura
#            Department of Astronomy and Earth Sciences, 
#                              Tokyo Gakugei University
#          e-mail: nishiura@u-gakugei.ac.jp
# 
