#
# <konic-obslog.cl>
#
# IRAF batch script for making electric observation-log of KONIC.
#
#                            2008.09.19.  Ver.0.0 Earliest version. 
#
# This IRAF batch script can make machine-readable observation-log  
# of KONIC image data. All konic raw data (KIR******.fits) should be  
# put in "RAW" directory and this directory should be put on current 
# directory. "konic-obslog", "konic-obslogJ", "konic-obslogH", and 
# "konic-obslogK" files will be output into "KONIC-obslog" directory.
#
# [USAGE] cl < konic-obslog.cl[RET]
#
# 0. Removing all temporal "___*.*" files.
#
!\rm ___*.*
!mkdir KONIC-obslog
#
# 1.0 Making raw-data list.
#
!ls -1 RAW/KIR*.fits > ___konic-raw0.lst
#
# 1.1 Extracting Object names.
#
imhe @___konic-raw0.lst l+ > ___konic-raw1.dat
#
!grep "OBJECT" ___konic-raw1.dat > ___konic-object0.dat
#
!awk '{print substr($3,2)}' ___konic-object0.dat > ___konic-object1.dat
#
# 1.2 Extracting Filter types.
#
!grep "FILTER" ___konic-raw1.dat > ___konic-filter0.dat
#
!awk '{print substr($3,2)}' ___konic-filter0.dat > ___konic-filter1.dat
#
# 1.3 Extracting exposure times.
#
!grep "EXPTIME" ___konic-raw1.dat > ___konic-exptime0.dat
#
!awk '{print $3}' ___konic-exptime0.dat > ___konic-exptime1.dat
#
# 1.4 Extracting JST
#
!grep "JST_STRT" ___konic-raw1.dat > ___konic-jst0.dat
#
!awk '{print substr($2,2)}' ___konic-jst0.dat > ___konic-jst1.dat
#
# 1.5 Extracting ZD
#
!grep "ZD" ___konic-raw1.dat > ___konic-zd0.dat
#
!awk '{print $3}' ___konic-zd0.dat > ___konic-zd1.dat
#
# 1.6 Outputing observation-log 
#
!paste ___konic-raw0.lst ___konic-object1.dat ___konic-filter1.dat ___konic-exptime1.dat ___konic-jst1.dat ___konic-zd1.dat > KONIC-obslog/konic-obslog 
#
# 1.7 Outputing observation-log for each filter-band.
#
!awk '{if($3=="J" || $3=="DARK"){print $1"  "$2"  "$3"  "$4"  "$5"  "$6}}' KONIC-obslog/konic-obslog > KONIC-obslog/konic-obslogJ 
!echo J-band observation-log have been output.
!awk '{if($3=="H" || $3=="DARK"){print $1"  "$2"  "$3"  "$4"  "$5"  "$6}}' KONIC-obslog/konic-obslog > KONIC-obslog/konic-obslogH 
!echo H-band observation-log have been output.
!awk '{if(substr($3,1,1)=="K" || $3=="DARK"){print $1"  "$2"  "$3"  "$4"  "$5"  "$6}}' KONIC-obslog/konic-obslog > KONIC-obslog/konic-obslogK 
!echo K-prime-band observation-log have been output.
#
# 1.7 Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
#
!echo Making observation-log of KONIC have been finished !
#
# End script.
#
#          Shingo Nishiura
#            Department of Astronomy and Earth Sciences, 
#                              Tokyo Gakugei University
#          e-mail: nishiura@u-gakugei.ac.jp
# 
