#!/bin/tcsh
#
# <konic-reform.cl>
#
# IRAF batch script for removing pre- and over-scan regions of KONIC data.
#
#                            2008.09.17.  Ver.0.0 Earliest version. 
#
# This IRAF batch script can remove pre-scan and over-scan regions of 
# KONIC image data. All konic raw data (KIR******.fits) should be put
# in "RAW" directory and this directory should be put on current 
# directory. Operated images (cpKIR******.fits) are put into "cpRAW" 
# directory.
#
# [USAGE] cl < konic-reform.cl[RET]
#
# 0. Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
#
# 1.0 Making raw-data list.
#
!mkdir cpRAW 
!ls -1 RAW/KIR*.fits > ___konic-raw.lst
#
# 1.1 Making basic images
#
!awk '{print "imcopy "$1"[1:1040,1:520] cpRAW/cp"substr($1,5,14) }' ___konic-raw.lst > ___kir01.cl
cl < ___kir01.cl
#
# 1.2 Copying down-half images 
#
!awk '{print "imcopy "$1"[1:1040,2:261] cpRAW/cp"substr($1,5,14)"[1:1040,1:260]"}' ___konic-raw.lst > ___kir02.cl
cl < ___kir02.cl
#
# 1.3 Copying up-half images
#
!awk '{print "imcopy "$1"[1:1040,264:523] cpRAW/cp"substr($1,5,14)"[1:1040,261:520]"}' ___konic-raw.lst > ___kir03.cl
cl < ___kir03.cl
#
# 1.4 Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
#
!echo KONIC data reforming have been finished !
#
# End script.
#
#          Shingo Nishiura
#            Department of Astronomy and Earth Sciences, 
#                              Tokyo Gakugei University
#          e-mail: nishiura@u-gakugei.ac.jp
# 
