#!/bin/tcsh
#
# <konic-sscomb.cl>
#
# IRAF batch-script to combine sky-subtracted upper-half image and lower-half one. 
#
#                            2008.09.30.  Ver.0.0 Earliest version. 
#
# This IRAF batch-script can combine sky-subtracted upper-half image and 
# lower-half one. 
# All sky-subtracted upper-half images (ss******U.fits) should be located 
# on "SSU" directory and lower-half images (ss******L.fits) should be 
# located on one named "SSL". 
# Combined flat-fielded images will output in "SS" diretory naming "ss******.fits". 
#
# [USAGE] cl < konic-sscomb.cl[RET]
#
# 0. Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
!mkdir SS
#
# 1.0 Making sky-subtracted image list.
#
!ls -1 SSU/ss*U.fits > ___konic-ssu.lst
!ls -1 SSL/ss*L.fits > ___konic-ssl.lst
#
# 1.1 Making combined image list. 
#
!awk '{print "SS/"substr($1,5,8)".fits"}' ___konic-ssu.lst > ___konic-ss.lst 
#
# 1.2 Making base-images with format of 1040x520
#
magnify input=@___konic-ssu.lst output=@___konic-ss.lst xmag=1 ymag=2 x1=1 x2=1040 dx=1 y1=1 y2=520 dy=1 fluxcon=yes
#
# 1.3 Image copying of upper-half images.
#
!awk '{print "imcopy "$1"[1:1040,1:260] SS/"substr($1,5,8)".fits[1:1040,261:520]"}' ___konic-ssu.lst > ___kir01.cl
cl < ___kir01.cl
#
# 1.4 Image copying of lower-half images.
#
!awk '{print "imcopy "$1"[1:1040,1:260] SS/"substr($1,5,8)".fits[1:1040,1:260]"}' ___konic-ssl.lst > ___kir02.cl
cl < ___kir02.cl
#
!\rm -rf ___*.*
#
!echo Sky-subtracted upper- and lower-images are combined! 
#
# End script.
#
#          Shingo Nishiura
#            Department of Astronomy and Earth Sciences, 
#                              Tokyo Gakugei University
#          e-mail: nishiura@u-gakugei.ac.jp
# 
