#
# <konic-ffobj.cl>
#
# IRAF batch script to subtracted skybackground from flat-fielded images.
#
#                            2008.09.30.  Ver.0.0 Earliest version. 
#
# This IRAF batch script subtracted skybackground from flat-fielded images. 
# Flat-fielded images should be located in "FFU" and "FFL" directories with 
# being named "ff******U.fits" and "ff******L.fits", respectively.
# This script will output "ss******U.fits" and "ss******L.fits" to "SSU" and 
# "SSL" directories.
#
# [USAGE] cl < konic-ssobj.cl[RET]
#
# 0. Removing all temporal "___*.*" files.
#
!\rm ___*.*
#
# 1.0 Making directory to put sky-subtracted images.
#
!\mkdir SSU
!\mkdir SSL
#
# 1.1 Making flat-fielded image lists.
#
!ls -1 FFU/ff*U.fits > ___ffobju.lst
!ls -1 FFL/ff*L.fits > ___ffobjl.lst
#
# 1.2 Making sky-subtracted image lists.
#
!awk '{print "SSU/ss"substr($1,7)}' ___ffobju.lst > ___ssobju.lst
!awk '{print "SSL/ss"substr($1,7)}' ___ffobjl.lst > ___ssobjl.lst

#
# 1.3 Sky-subtraction 
#
imsurfit input=@___ffobju.lst output=@___ssobju.lst xorder=1 yorder=1 type_ou= residual cross_t=no xmedian=64 ymedian=64 median_=50 lower=3 upper=3
imsurfit input=@___ffobjl.lst output=@___ssobjl.lst xorder=1 yorder=1 type_ou= residual cross_t=no xmedian=64 ymedian=64 median_=50 lower=3 upper=3
#
# 2.0 Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
#
!echo Sky-subtraction of flat-fielded images have been finished.
#
# End script.
#
#          Shingo Nishiura
#            Department of Astronomy and Earth Sciences, 
#                              Tokyo Gakugei University
#          e-mail: nishiura@u-gakugei.ac.jp
# 
