#
# <konic-ssobjK.cl>
#
# IRAF batch script for sky-background subtraction from flat-fielded K'-band object frames.
#
#                            2008.09.22.  Ver.0.0 Earliest version. 
#
# This IRAF batch script can subtract sky-background from flat-fielded 
# K'-band object frames.  
# Flat-fielded object images should be put in "FF" directory.
# This script will make "SS" directory in current directory and output 
# "ss*.fits" files in it.
#
# [USAGE] cl < konic-ssobjK.cl[RET]
#
# 0. Removing all temporal "___*.*" files.
#
!\rm ___*.*
#
# 1.0 Making directory to put sky-subtracted images.
#
!\mkdir SS
#
# 1.1 Making data list.
#
!ls -1 FF/ff*.fits > ___ffobj.lst
imhe @___ffobj.lst l+ > ___konic-ffobj.dat 
#
# 1.2 Extracting Object names.
#
!grep "OBJECT" ___konic-ffobj.dat > ___konic-ffobj0.dat
!awk '{print substr($3,2)}' ___konic-ffobj0.dat > ___konic-ffobj1.dat
#
# 1.3 Extracting Filter types.
#
!grep "FILTER" ___konic-ffobj.dat > ___konic-filter0.dat
!awk '{print substr($3,2)}' ___konic-filter0.dat > ___konic-filter1.dat
#
# 1.4 Outputing observation-log.
#
!paste ___ffobj.lst ___konic-ffobj1.dat ___konic-filter1.dat > ___simple-obs.log
#
# 1.5 Flat-fielding dark subtracted frames.
#
!awk '{if(substr($3,1,1)=="K"){print $1}}' ___simple-obs.log > ___ffobjK.lst
!awk '{print "SS/ss"substr($1,6)}' ___ffobjK.lst > ___ssobjK.lst
imsurfit input=@___ffobjK.lst output=@___ssobjK.lst xorder=2 yorder=2 type_ou=residual functio=leg cross_t=no xmedian=128 ymedian=128
#
# 2.0 Removing all temporal "___*.*" files.
#
!\rm -rf ___*.*
#
!echo K'-band sky-background subtraction have been finished.
#
# End script.
#
#          Shingo Nishiura
#            Department of Astronomy and Earth Sciences, 
#                              Tokyo Gakugei University
#          e-mail: nishiura@u-gakugei.ac.jp
# 
